@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: bbs_thread_ui.c,v 1.50 2003/12/12 21:43:52 fuyu Exp $
+ * $Id: bbs_thread_ui.c,v 1.51 2003/12/13 07:21:06 fuyu Exp $
  */
 
 #include "config.h"
@@ -977,31 +977,57 @@ ensure_popup_context(BBSThreadView *parent, OchushaBBSThread *thread,
 	}
 
       renderer_context->transparent_a_bone = TRUE;
-      if (a_bone_by_name
-	  && a_bone_by_name_pattern != NULL && *a_bone_by_name_pattern != '\0')
-	renderer_context->a_bone_by_name
-	  = oniguruma_regex_new(a_bone_by_name_pattern, NULL);
-      if (a_bone_by_id
-	  && a_bone_by_id_pattern != NULL && *a_bone_by_id_pattern != '\0')
-	renderer_context->a_bone_by_id
-	  = oniguruma_regex_new(a_bone_by_id_pattern, NULL);
-      if (a_bone_by_content
-	  && a_bone_by_content_pattern != NULL
-	  && *a_bone_by_content_pattern != '\0')
+      if (a_bone_by_name || a_bone_by_id || a_bone_by_content)
 	{
 	  const char *encoding
 	    = ochusha_bbs_thread_get_response_character_encoding(thread);
 	  iconv_t converter = iconv_open(encoding, "UTF-8");
 	  if (converter != (iconv_t)-1)
 	    {
-	      char *pattern
-		= convert_string(converter, NULL,
-				 a_bone_by_content_pattern, -1);
-	      if (pattern != NULL && *pattern != '\0')
-		renderer_context->a_bone_by_content
-		  = oniguruma_regex_new(pattern, encoding);
+	      if (a_bone_by_name
+		  && a_bone_by_name_pattern != NULL
+		  && *a_bone_by_name_pattern != '\0')
+		{
+		  char *pattern = convert_string(converter, NULL,
+						 a_bone_by_name_pattern, -1);
+		  if (pattern != NULL)
+		    {
+		      if (*pattern != '\0')
+			renderer_context->a_bone_by_name
+			  = oniguruma_regex_new(pattern, encoding);
+		      G_FREE(pattern);
+		    }
+		}
+	      if (a_bone_by_id
+		  && a_bone_by_id_pattern != NULL
+		  && *a_bone_by_id_pattern != '\0')
+		{
+		  char *pattern = convert_string(converter, NULL,
+						 a_bone_by_id_pattern, -1);
+		  if (pattern != NULL)
+		    {
+		      if (*pattern != '\0')
+			renderer_context->a_bone_by_id
+			  = oniguruma_regex_new(pattern, encoding);
+		      G_FREE(pattern);
+		    }
+		}
+	      if (a_bone_by_content
+		  && a_bone_by_content_pattern != NULL
+		  && *a_bone_by_content_pattern != '\0')
+		{
+		  char *pattern = convert_string(converter, NULL,
+						 a_bone_by_content_pattern,
+						 -1);
+		  if (pattern != NULL)
+		    {
+		      if (*pattern != '\0')
+			renderer_context->a_bone_by_content
+			  = oniguruma_regex_new(pattern, encoding);
+		      G_FREE(pattern);
+		    }
+		}
 	      iconv_close(converter);
-	      G_FREE(pattern);
 	    }
 	}
     }
@@ -1185,6 +1211,13 @@ render_bbs_thread(WorkerThread *employee, gpointer args)
       bbs_thread_view_get_tag_by_name(job_args->view, "response_name"),
       bbs_thread_view_get_tag_by_name(job_args->view, "response_paragraph"),
       bbs_thread_view_get_tag_by_name(job_args->view, "bold"),
+
+      FALSE,					/* transparent_a_bone */
+      NULL,					/* a_bone_by_name regex_obj */
+      NULL,					/* a_bone_by_id */
+      NULL,					/* a_bone_by_content */
+      						/* regex_t */
+      						/* regex_t */
   };
 
   gboolean a_bone_by_name;
@@ -1244,29 +1277,58 @@ render_bbs_thread(WorkerThread *employee, gpointer args)
     }
 
   context.transparent_a_bone = application->enable_transparent_a_bone;
-  if (a_bone_by_name
-      && a_bone_by_name_pattern != NULL && *a_bone_by_name_pattern != '\0')
-    context.a_bone_by_name = oniguruma_regex_new(a_bone_by_name_pattern, NULL);
-  if (a_bone_by_id
-      && a_bone_by_id_pattern != NULL && *a_bone_by_id_pattern != '\0')
-    context.a_bone_by_id = oniguruma_regex_new(a_bone_by_id_pattern, NULL);
-  if (a_bone_by_content
-      && a_bone_by_content_pattern != NULL
-      && *a_bone_by_content_pattern != '\0')
+  if (a_bone_by_name || a_bone_by_id || a_bone_by_content)
     {
       const char *encoding
 	= ochusha_bbs_thread_get_response_character_encoding(thread);
       iconv_t converter = iconv_open(encoding, "UTF-8");
       if (converter != (iconv_t)-1)
 	{
-	  char *pattern
-	    = convert_string(converter, NULL,
-			     a_bone_by_content_pattern, -1);
-	  if (pattern != NULL && *pattern != '\0')
-	    context.a_bone_by_content = oniguruma_regex_new(pattern,
-							    encoding);
+	  if (a_bone_by_name
+	      && a_bone_by_name_pattern != NULL
+	      && *a_bone_by_name_pattern != '\0')
+	    {
+	      char *pattern = convert_string(converter, NULL,
+					     a_bone_by_name_pattern, -1);
+	      if (pattern != NULL)
+		{
+		  if (*pattern != '\0')
+		    context.a_bone_by_name = oniguruma_regex_new(pattern,
+								 encoding);
+		  G_FREE(pattern);
+		}
+	    }
+	  if (a_bone_by_id
+	      && a_bone_by_id_pattern != NULL
+	      && *a_bone_by_id_pattern != '\0')
+	    {
+	      char *pattern = convert_string(converter, NULL,
+					     a_bone_by_id_pattern, -1);
+	      if (pattern != NULL)
+		{
+		  if (*pattern != '\0')
+		    context.a_bone_by_id = oniguruma_regex_new(pattern,
+							       encoding);
+		  G_FREE(pattern);
+		}
+	    }
+	  if (a_bone_by_content
+	      && a_bone_by_content_pattern != NULL
+	      && *a_bone_by_content_pattern != '\0')
+	    {
+	      char *pattern
+		= convert_string(converter, NULL,
+				 a_bone_by_content_pattern, -1);
+	      if (pattern != NULL)
+		{
+		  if (*pattern != '\0')
+		    context.a_bone_by_content = oniguruma_regex_new(pattern,
+								    encoding);
+		  G_FREE(pattern);
+		}
+	    }
+
 	  iconv_close(converter);
-	  G_FREE(pattern);
 	}
     }
 
