@@ -23,12 +23,14 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: bbs_thread_ui.h,v 1.12 2003/12/08 04:27:10 fuyu Exp $
+ * $Id: bbs_thread_ui.h,v 1.13 2003/12/12 21:43:52 fuyu Exp $
  */
 
 #ifndef _BBSTHREAD_UI_H_
 #define _BBSTHREAD_UI_H_
 
+#include "config.h"
+
 #include "ochusha_ui.h"
 #include "ochusha_bbs_thread.h"
 #include "ochusha_async_buffer.h"
@@ -92,6 +94,18 @@ typedef struct _BBSThreadGUIInfo
 
   /* Ǹν񤭹߻Υᥤ */
   gchar *last_mail;
+
+  /* ܡ */
+  gboolean thread_local_a_bone;
+
+  gboolean a_bone_by_name;
+  gchar *a_bone_by_name_pattern;
+
+  gboolean a_bone_by_id;
+  gchar *a_bone_by_id_pattern;
+
+  gboolean a_bone_by_content;
+  gchar *a_bone_by_content_pattern;
 } BBSThreadGUIInfo;
 
 
