@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: bbs_thread_view.c,v 1.25 2003/12/08 04:27:10 fuyu Exp $
+ * $Id: bbs_thread_view.c,v 1.26 2003/12/12 21:43:52 fuyu Exp $
  */
 
 #include "config.h"
@@ -42,12 +42,10 @@
 #include <glib.h>
 #include <gtk/gtk.h>
 
-#if ENABLE_ONIGURUMA
-# if HAVE_ONIG_ONIGPOSIX_H
-#   include <onig/onigposix.h>
-# else
-#   include <onigposix.h>
-# endif
+#if HAVE_ONIG_ONIGPOSIX_H
+# include <onig/onigposix.h>
+#else
+# include <onigposix.h>
 #endif
 
 #include <stdio.h>
@@ -538,7 +536,6 @@ bbs_thread_view_destroy(GtkObject *object)
       view->search_key = NULL;
     }
 
-#if ENABLE_ONIGURUMA
   if (view->regexp_available)
     {
       regfree(&view->regexp);
@@ -549,7 +546,6 @@ bbs_thread_view_destroy(GtkObject *object)
 	  view->regexp_match = NULL;
 	}
     }
-#endif
 
   if (GTK_OBJECT_CLASS(parent_class)->destroy)
     (*GTK_OBJECT_CLASS(parent_class)->destroy)(object);
@@ -1298,9 +1294,6 @@ bbs_thread_view_find_forward_first_match(BBSThreadView *view,
 {
   gboolean result = FALSE;
   gchar *text;
-#if !ENABLE_ONIGURUMA
-  g_return_val_if_fail(!view->use_regexp, FALSE);
-#endif
   /*
    * MEMO: gtk_text_iter_get_text()䤽֤ϥԡ֤Ƥ뤳Ȥ
    *       աХåեΤоݤ˸ȤʤȡХåեݤȤΥԡ
@@ -1333,7 +1326,6 @@ bbs_thread_view_find_forward_first_match(BBSThreadView *view,
 
   if (view->use_regexp)
     {
-#if ENABLE_ONIGURUMA
       g_assert(view->regexp_available);
 
       if (regexec(&view->regexp, text, 1, view->regexp_match, 0) == 0)
@@ -1348,9 +1340,6 @@ bbs_thread_view_find_forward_first_match(BBSThreadView *view,
 	    + (*match_start_offset_p);
 	  result = TRUE;
 	}
-#else
-      /* ºݤˤ뤳ȤϤʤ */
-#endif
     }
   else
     {
@@ -1382,9 +1371,6 @@ bbs_thread_view_find_backward_first_match(BBSThreadView *view,
 {
   gboolean result = FALSE;
   gchar *text;
-#if !ENABLE_ONIGURUMA
-  g_return_val_if_fail(!view->use_regexp, FALSE);
-#endif
   /*
    * MEMO: gtk_text_iter_get_text()䤽֤ϥԡ֤Ƥ뤳Ȥ
    *       աХåեΤоݤ˸ȤʤȡХåեݤȤΥԡ
@@ -1402,7 +1388,6 @@ bbs_thread_view_find_backward_first_match(BBSThreadView *view,
 
   if (view->use_regexp)
     {
-#if ENABLE_ONIGURUMA
       /*
        * MEMO: ɽεսޥåˤϤޤˡ̵ʤΤǡ٤
        *       (ޥåʸ¿)ǰξO(n)regexec()¹Ԥ롣
@@ -1433,9 +1418,6 @@ bbs_thread_view_find_backward_first_match(BBSThreadView *view,
 	    + (*match_start_offset_p);
 	  result = TRUE;
 	}
-#else
-      /* ºݤˤ뤳ȤϤʤ */
-#endif
     }
   else
     {
@@ -1467,10 +1449,6 @@ bbs_thread_view_do_search_forward(BBSThreadView *view,
   gint start_offset = 0;
   gint end_offset = 0;
 
-#if !ENABLE_ONIGURUMA
-  g_return_val_if_fail(!view->use_regexp, FALSE);
-#endif
-
   if (view->use_regexp)
     {
       if (!view->regexp_available)
@@ -1518,10 +1496,6 @@ bbs_thread_view_do_search_backward(BBSThreadView *view,
   gint start_offset = 0;
   gint end_offset = 0;
 
-#if !ENABLE_ONIGURUMA
-  g_return_val_if_fail(!view->use_regexp, FALSE);
-#endif
-
   if (view->use_regexp)
     {
       if (!view->regexp_available)
@@ -1609,7 +1583,6 @@ bbs_thread_view_find(BBSThreadView *view, const gchar *key,
       view->search_key = NULL;
     }
 
-#if ENABLE_ONIGURUMA
   if (use_regexp)
     {
       int regcomp_result;
@@ -1657,22 +1630,6 @@ bbs_thread_view_find(BBSThreadView *view, const gchar *key,
 #endif
     }
   view->use_regexp = use_regexp;
-#else
-  if (match_case)
-    view->search_key = G_STRDUP(key);
-  else
-#if TRACE_MEMORY_USAGE
-    {
-      gchar *tmp_key = g_utf8_casefold(key, -1);
-      view->search_key = G_STRDUP(tmp_key);
-      g_free(tmp_key);
-    }
-#else
-    view->search_key = g_utf8_casefold(key, -1);
-#endif
-  view->use_regexp = FALSE;
-  view->regexp_available = FALSE;
-#endif
 
   if (result)
     {
@@ -1719,7 +1676,6 @@ bbs_thread_view_invalidate_search_result(BBSThreadView *view)
       view->search_key = NULL;
     }
 
-#if ENABLE_ONIGURUMA
   if (view->regexp_available)
     {
       regfree(&view->regexp);
@@ -1730,7 +1686,6 @@ bbs_thread_view_invalidate_search_result(BBSThreadView *view)
 	  view->regexp_match = NULL;
 	}
     }
-#endif
 
   view->last_match_offset = 0;
 }
