@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: bbs_thread_view.h,v 1.15 2003/12/07 16:57:58 fuyu Exp $
+ * $Id: bbs_thread_view.h,v 1.16 2003/12/12 21:43:52 fuyu Exp $
  */
 
 #ifndef _BBS_THREAD_VIEW_H_
@@ -33,12 +33,10 @@
 
 #include <gtk/gtk.h>
 
-#if ENABLE_ONIGURUMA
-# if HAVE_ONIG_ONIGPOSIX_H
-#  include <onig/onigposix.h>
-# else
-#  include <onigposix.h>
-# endif
+#if HAVE_ONIG_ONIGPOSIX_H
+# include <onig/onigposix.h>
+#else
+# include <onigposix.h>
 #endif
 
 #ifdef __cplusplus
@@ -99,10 +97,8 @@ struct _BBSThreadView
 
 
   gchar *search_key;
-#if ENABLE_ONIGURUMA
   regex_t regexp;
   regmatch_t *regexp_match;
-#endif
   guint alt_link_tag		: 1;
   guint alt_sage_tag		: 1;
   guint last_is_new_line	: 1;
