@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_ui.c,v 1.43 2003/12/07 16:57:58 fuyu Exp $
+ * $Id: ochusha_ui.c,v 1.44 2003/12/12 21:43:52 fuyu Exp $
  */
 
 #include "config.h"
@@ -42,6 +42,7 @@
 
 #include "icon_label.h"
 #include "paned_notebook.h"
+#include "regex_utils.h"
 
 #include "ugly_gtk2utils.h"
 
@@ -49,14 +50,6 @@
 #include <gtk/gtk.h>
 #include <gdk-pixbuf/gdk-pixdata.h>
 
-#if ENABLE_ONIGURUMA
-# if HAVE_ONIG_ONIGPOSIX_H
-#  include <onig/onigposix.h>
-# else
-#  include <onigposix.h>
-# endif
-#endif
-
 #include <pthread.h>
 
 #include <stdio.h>
@@ -459,10 +452,6 @@ ochusha_init_application(OchushaApplication *application)
 #endif
 #endif	/* ENABLE_MAIN_TOOLBAR */
 
-#if ENABLE_ONIGURUMA
-  reg_set_encoding(REG_ENCODING_UTF8);
-#endif
-
   /* ν */
   initialize_open_url_dialog(application);
 
@@ -1023,10 +1012,22 @@ write_optional_prefs(FILE *file, gpointer user_data)
   OUTPUT_CONFIG_ATTRIBUTE_STRING(file, application, threadlist_view_contents);
 
   OUTPUT_CONFIG_ATTRIBUTE_STRING(file, application, thread_view_font_name);
+  OUTPUT_CONFIG_ATTRIBUTE_BOOLEAN(file, application,
+				  enable_transparent_a_bone);
+  OUTPUT_CONFIG_ATTRIBUTE_BOOLEAN(file, application, disable_popup_a_bone);
 
   OUTPUT_CONFIG_ATTRIBUTE_BOOLEAN(file, application, default_open_in_tab);
   OUTPUT_CONFIG_ATTRIBUTE_INT(file, application, show_mailto_mode);
 
+  OUTPUT_CONFIG_ATTRIBUTE_BOOLEAN(file, application, a_bone_by_name);
+  OUTPUT_CONFIG_ATTRIBUTE_STRING(file, application, a_bone_by_name_pattern);
+
+  OUTPUT_CONFIG_ATTRIBUTE_BOOLEAN(file, application, a_bone_by_id);
+  OUTPUT_CONFIG_ATTRIBUTE_STRING(file, application, a_bone_by_id_pattern);
+
+  OUTPUT_CONFIG_ATTRIBUTE_BOOLEAN(file, application, a_bone_by_content);
+  OUTPUT_CONFIG_ATTRIBUTE_STRING(file, application,
+				 a_bone_by_content_pattern);
 
   OUTPUT_CONFIG_ATTRIBUTE_BOOLEAN(file, application, enable_popup_title);
   OUTPUT_CONFIG_ATTRIBUTE_INT(file, application, popup_title_delay);
@@ -1114,7 +1115,17 @@ configure_application(OchushaApplication *application)
 
       /* ɽϢ */
       application->thread_view_font_name = NULL;
+      application->enable_transparent_a_bone = FALSE;
+      application->disable_popup_a_bone = FALSE;
+
+      application->default_open_in_tab = FALSE;
       application->show_mailto_mode = OCHUSHA_DEFAULT_SHOW_MAILTO_MODE;
+      application->a_bone_by_name = FALSE;
+      application->a_bone_by_name_pattern = G_STRDUP("");
+      application->a_bone_by_id = FALSE;
+      application->a_bone_by_id_pattern = G_STRDUP("");
+      application->a_bone_by_content = FALSE;
+      application->a_bone_by_content_pattern = G_STRDUP("");
 
 
       /* 쥿Υݥåץå״Ϣ */
@@ -1296,11 +1307,18 @@ read_optional_prefs(GHashTable *pref_attrs, gpointer user_data)
     application->threadlist_view_contents
       = G_STRDUP(OCHUSHA_DEFAULT_THREADLIST_VIEW_CONTENTS);
 
+  application->default_open_in_tab
+    = ochusha_utils_get_attribute_boolean(pref_attrs, "default_open_in_tab");
+
   application->thread_view_font_name
     = ochusha_utils_get_attribute_string(pref_attrs, "thread_view_font_name");
 
-  application->default_open_in_tab
-    = ochusha_utils_get_attribute_boolean(pref_attrs, "default_open_in_tab");
+  application->enable_transparent_a_bone
+    = ochusha_utils_get_attribute_boolean(pref_attrs,
+					  "enable_transparent_a_bone");
+  application->disable_popup_a_bone
+    = ochusha_utils_get_attribute_boolean(pref_attrs,
+					  "disable_popup_a_bone");
 
   application->show_mailto_mode
     = (ThreadViewMailtoMode)ochusha_utils_get_attribute_int(pref_attrs,
@@ -1309,6 +1327,28 @@ read_optional_prefs(GHashTable *pref_attrs, gpointer user_data)
       || application->show_mailto_mode > THREAD_VIEW_MAILTO_MODE_HIDE)
     application->show_mailto_mode = THREAD_VIEW_MAILTO_MODE_DEFAULT;
 
+  application->a_bone_by_name
+    = ochusha_utils_get_attribute_boolean(pref_attrs, "a_bone_by_name");
+  application->a_bone_by_name_pattern
+    = ochusha_utils_get_attribute_string(pref_attrs, "a_bone_by_name_pattern");
+  if (application->a_bone_by_name_pattern == NULL)
+    application->a_bone_by_name_pattern = G_STRDUP("");
+
+  application->a_bone_by_id
+    = ochusha_utils_get_attribute_boolean(pref_attrs, "a_bone_by_id");
+  application->a_bone_by_id_pattern
+    = ochusha_utils_get_attribute_string(pref_attrs, "a_bone_by_id_pattern");
+  if (application->a_bone_by_id_pattern == NULL)
+    application->a_bone_by_id_pattern = G_STRDUP("");
+
+  application->a_bone_by_content
+    = ochusha_utils_get_attribute_boolean(pref_attrs, "a_bone_by_content");
+  application->a_bone_by_content_pattern
+    = ochusha_utils_get_attribute_string(pref_attrs,
+					 "a_bone_by_content_pattern");
+  if (application->a_bone_by_content_pattern == NULL)
+    application->a_bone_by_content_pattern = G_STRDUP("");
+
   if (g_hash_table_lookup(pref_attrs, "enable_popup_title") != NULL)
     application->enable_popup_title
       = ochusha_utils_get_attribute_boolean(pref_attrs, "enable_popup_title");
@@ -1735,6 +1775,22 @@ preference_dialog_response_cb(GtkWidget *widget, gint response_id,
 	      = gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(tmp_data));
 	  }
 
+	tmp_data = g_object_get_data(G_OBJECT(widget),
+				     "enable_transparent_a_bone");
+	if (tmp_data != NULL)
+	  {
+	    application->enable_transparent_a_bone
+	      = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(tmp_data));
+	  }
+
+	tmp_data = g_object_get_data(G_OBJECT(widget),
+				     "disable_popup_a_bone");
+	if (tmp_data != NULL)
+	  {
+	    application->disable_popup_a_bone
+	      = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(tmp_data));
+	  }
+
 	tmp_data = g_object_get_data(G_OBJECT(widget),
 				     "show_mailto_literally");
 	if (tmp_data != NULL)
@@ -1745,6 +1801,57 @@ preference_dialog_response_cb(GtkWidget *widget, gint response_id,
 		 : THREAD_VIEW_MAILTO_MODE_HIDE);
 	  }
 
+	tmp_data = g_object_get_data(G_OBJECT(widget), "a_bone_by_name");
+	if (tmp_data != NULL)
+	  {
+	    application->a_bone_by_name
+	      = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(tmp_data));
+	  }
+
+	tmp_data = g_object_get_data(G_OBJECT(widget),
+				     "a_bone_by_name_pattern");
+	if (tmp_data != NULL)
+	  {
+	    if (application->a_bone_by_name_pattern != NULL)
+	      G_FREE(application->a_bone_by_name_pattern);
+	    application->a_bone_by_name_pattern
+	      = regex_editor_get_regex_text(REGEX_EDITOR(tmp_data));
+	  }
+
+	tmp_data = g_object_get_data(G_OBJECT(widget), "a_bone_by_id");
+	if (tmp_data != NULL)
+	  {
+	    application->a_bone_by_id
+	      = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(tmp_data));
+	  }
+
+	tmp_data = g_object_get_data(G_OBJECT(widget),
+				     "a_bone_by_id_pattern");
+	if (tmp_data != NULL)
+	  {
+	    if (application->a_bone_by_id_pattern != NULL)
+	      G_FREE(application->a_bone_by_id_pattern);
+	    application->a_bone_by_id_pattern
+	      = regex_editor_get_regex_text(REGEX_EDITOR(tmp_data));
+	  }
+
+	tmp_data = g_object_get_data(G_OBJECT(widget), "a_bone_by_content");
+	if (tmp_data != NULL)
+	  {
+	    application->a_bone_by_content
+	      = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(tmp_data));
+	  }
+
+	tmp_data = g_object_get_data(G_OBJECT(widget),
+				     "a_bone_by_content_pattern");
+	if (tmp_data != NULL)
+	  {
+	    if (application->a_bone_by_content_pattern != NULL)
+	      G_FREE(application->a_bone_by_content_pattern);
+	    application->a_bone_by_content_pattern
+	      = regex_editor_get_regex_text(REGEX_EDITOR(tmp_data));
+	  }
+
 	tmp_data = g_object_get_data(G_OBJECT(widget), "default_open_in_tab");
 	if (tmp_data != NULL)
 	  {
@@ -2120,6 +2227,22 @@ build_thread_view_setting_frame(OchushaApplication *application,
   gtk_box_pack_start(GTK_BOX(outer_vbox), hbox, FALSE, FALSE, 0);
 
 
+  tmp_widget = gtk_check_button_new_with_label(_("Enable transparent a bone."));
+  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(tmp_widget),
+			       application->enable_transparent_a_bone);
+  gtk_widget_show(tmp_widget);
+  gtk_box_pack_start(GTK_BOX(outer_vbox), tmp_widget, FALSE, FALSE, 0);
+  g_object_set_data(G_OBJECT(dialog), "enable_transparent_a_bone",
+		    tmp_widget);
+
+  tmp_widget = gtk_check_button_new_with_label(_("Disable popup of response made a bone."));
+  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(tmp_widget),
+			       application->disable_popup_a_bone);
+  gtk_widget_show(tmp_widget);
+  gtk_box_pack_start(GTK_BOX(outer_vbox), tmp_widget, FALSE, FALSE, 0);
+  g_object_set_data(G_OBJECT(dialog), "disable_popup_a_bone", tmp_widget);
+
+
 
   thread_frame = gtk_frame_new(_("Default Setting of Thread Views"));
   gtk_frame_set_shadow_type(GTK_FRAME(thread_frame), GTK_SHADOW_ETCHED_OUT);
@@ -2134,10 +2257,51 @@ build_thread_view_setting_frame(OchushaApplication *application,
 			       application->show_mailto_mode
 			       == THREAD_VIEW_MAILTO_MODE_SHOW);
   gtk_widget_show(tmp_widget);
-  gtk_box_pack_start(GTK_BOX(vbox), tmp_widget, FALSE, FALSE, 5);
+  gtk_box_pack_start(GTK_BOX(vbox), tmp_widget, FALSE, FALSE, 0);
   g_object_set_data(G_OBJECT(dialog), "show_mailto_literally",
 		    tmp_widget);
 
+
+  tmp_widget = gtk_check_button_new_with_label(_("A bone by name field."));
+  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(tmp_widget),
+			       application->a_bone_by_name);
+  gtk_widget_show(tmp_widget);
+  gtk_box_pack_start(GTK_BOX(vbox), tmp_widget, FALSE, FALSE, 0);
+  g_object_set_data(G_OBJECT(dialog), "a_bone_by_name", tmp_widget);
+
+  tmp_widget = regex_editor_new(application->a_bone_by_name_pattern);
+  gtk_widget_show(tmp_widget);
+  gtk_box_pack_start(GTK_BOX(vbox), tmp_widget, TRUE, TRUE, 0);
+  g_object_set_data(G_OBJECT(dialog), "a_bone_by_name_pattern", tmp_widget);
+
+
+  tmp_widget = gtk_check_button_new_with_label(_("A bone by ID."));
+  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(tmp_widget),
+			       application->a_bone_by_id);
+  gtk_widget_show(tmp_widget);
+  gtk_box_pack_start(GTK_BOX(vbox), tmp_widget, FALSE, FALSE, 0);
+  g_object_set_data(G_OBJECT(dialog), "a_bone_by_id", tmp_widget);
+
+  tmp_widget = regex_editor_new(application->a_bone_by_id_pattern);
+  gtk_widget_show(tmp_widget);
+  gtk_box_pack_start(GTK_BOX(vbox), tmp_widget, TRUE, TRUE, 0);
+  g_object_set_data(G_OBJECT(dialog), "a_bone_by_id_pattern", tmp_widget);
+
+
+  tmp_widget = gtk_check_button_new_with_label(_("A bone by content."));
+  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(tmp_widget),
+			       application->a_bone_by_content);
+  gtk_widget_show(tmp_widget);
+  gtk_box_pack_start(GTK_BOX(vbox), tmp_widget, FALSE, FALSE, 0);
+  g_object_set_data(G_OBJECT(dialog), "a_bone_by_content", tmp_widget);
+
+  tmp_widget = regex_editor_new(application->a_bone_by_content_pattern);
+  gtk_widget_show(tmp_widget);
+  gtk_box_pack_start(GTK_BOX(vbox), tmp_widget, TRUE, TRUE, 0);
+  g_object_set_data(G_OBJECT(dialog), "a_bone_by_content_pattern",
+		    tmp_widget);
+
+
   gtk_widget_show(thread_frame);
   gtk_box_pack_start(GTK_BOX(outer_vbox), thread_frame, TRUE, TRUE, 5);
 
