@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_async_buffer.h,v 1.4 2003/06/06 19:38:04 fuyu Exp $
+ * $Id: ochusha_async_buffer.h,v 1.7 2003/12/04 07:30:42 fuyu Exp $
  */
 
 #ifndef _OCHUSHA_ASYNCBUF_H_
@@ -81,13 +81,15 @@ struct _OchushaAsyncBuffer
   BufferSyncObject *sync_object;
   DestructFunc *destructor;
 
-  volatile int number_of_lock_waiters;
+  volatile unsigned int number_of_lock_waiters;
 };
 
 
 struct _OchushaAsyncBufferClass
 {
   GObjectClass parent_class;
+
+  void (*wakeup_now)(OchushaAsyncBuffer *buffer);
 };
 
 
