@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_bbs_thread.c,v 1.15 2003/11/26 09:59:07 fuyu Exp $
+ * $Id: ochusha_bbs_thread.c,v 1.16 2003/12/08 02:29:45 fuyu Exp $
  */
 
 #include "config.h"
@@ -406,6 +406,7 @@ gboolean
 ochusha_bbs_thread_parse_responses(OchushaBBSThread *thread,
 				   OchushaAsyncBuffer *buffer,
 				   int start, int number,
+				   gboolean no_wait,
 				   StartThreadCallback *start_thread_cb,
 				   EachResponseCallback *each_response_cb,
 				   BrokenResponseCallback *broken_response_cb,
@@ -419,7 +420,7 @@ ochusha_bbs_thread_parse_responses(OchushaBBSThread *thread,
   klass = OCHUSHA_BBS_THREAD_GET_CLASS(thread);
   g_return_val_if_fail(klass->parse_responses != NULL, FALSE);
 
-  return (*klass->parse_responses)(thread, buffer, start, number,
+  return (*klass->parse_responses)(thread, buffer, start, number, no_wait,
 				   start_thread_cb, each_response_cb,
 				   broken_response_cb, end_thread_cb,
 				   callback_data);
