@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_board_jbbs.c,v 1.3 2003/12/07 16:57:58 fuyu Exp $
+ * $Id: ochusha_board_jbbs.c,v 1.4 2003/12/12 21:42:40 fuyu Exp $
  */
 
 #include "config.h"
@@ -40,12 +40,10 @@
 #include <glib-object.h>
 #include <glib.h>
 
-#if ENABLE_ONIGURUMA
-# if HAVE_ONIG_ONIGPOSIX_H
-#  include <onig/onigposix.h>
-# else
-#  include <onigposix.h>
-# endif
+#if HAVE_ONIG_ONIGPOSIX_H
+# include <onig/onigposix.h>
+#else
+# include <onigposix.h>
 #endif
 
 #include <stdio.h>
@@ -911,7 +909,6 @@ refresh_threadlist_by_subject_txt(OchushaBulletinBoard *board,
 }
 
 
-#if defined(ENABLE_ONIGURUMA)
 /*
  * refresh_threadlist_by_subback_html:
  *
@@ -1135,7 +1132,6 @@ refresh_threadlist_by_subback_html(OchushaBulletinBoard *board,
 
   return result;
 }
-#endif
 
 
 /*
@@ -1155,7 +1151,6 @@ ochusha_board_jbbs_refresh_threadlist(OchushaBulletinBoard *board,
 				      EachThreadCallback *each_thread_cb,
 				      gpointer callback_data)
 {
-#if defined(ENABLE_ONIGURUMA)
   switch (board->bbs_type)
     {
     case OCHUSHA_BBS_TYPE_MITINOKU:
@@ -1166,8 +1161,4 @@ ochusha_board_jbbs_refresh_threadlist(OchushaBulletinBoard *board,
       return refresh_threadlist_by_subject_txt(board, buffer,
 					       each_thread_cb, callback_data);
     }
-#else
-  return refresh_threadlist_by_subject_txt(board, buffer,
-					   each_thread_cb, callback_data);
-#endif
 }
