@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_network_broker.c,v 1.27 2003/12/08 05:01:06 fuyu Exp $
+ * $Id: ochusha_network_broker.c,v 1.30 2003/12/11 18:04:19 fuyu Exp $
  */
 
 #include "config.h"
@@ -508,18 +508,133 @@ typedef struct _NetworkBrokerJobArgs
 
 /*
  * OchushaAsyncBufferworker_sync_object_idqdataȤƤäĤ롣
- * ݽϡǸtimeout_cb
  */
-typedef struct _WorkerSyncObject
+#define OCHUSHA_TYPE_WORKER_SYNC_OBJECT			(worker_sync_object_get_type())
+#define OCHUSHA_WORKER_SYNC_OBJECT(obj)			(G_TYPE_CHECK_INSTANCE_CAST((obj), OCHUSHA_TYPE_WORKER_SYNC_OBJECT, WorkerSyncObject))
+#define OCHUSHA_WORKER_SYNC_OBJECT_CLASS(klass)		(G_TYPE_CHECK_CLASS_CAST((klass), OCHUSHA_TYPE_WORKER_SYNC_OBJECT, WorkerSyncObjectClass))
+#define OCHUSHA_IS_WORKER_SYNC_OBJECT(obj)		(G_TYPE_CHECK_INSTANCE_TYPE((obj), OCHUSHA_TYPE_WORKER_SYNC_OBJECT))
+#define OCHUSHA_IS_WORKER_SYNC_OBJECT_CLASS(klass)	(G_TYPE_CHECK_CLASS_TYPE((klass), OCHUSHA_TYPE_WORKER_SYNC_OBJECT))
+#define OCHUSHA_WORKER_SYNC_OBJECT_GET_CLASS(obj)	(G_TYPE_INSTANCE_GET_CLASS((obj), OCHUSHA_TYPE_WORKER_SYNC_OBJECT, WorkerSyncObjectClass))
+
+
+typedef struct _WorkerSyncObject WorkerSyncObject;
+typedef struct _WorkerSyncObjectClass WorkerSyncObjectClass;
+
+struct _WorkerSyncObject
 {
+  GObject parent_object;
+
   pthread_mutex_t lock;
   pthread_cond_t cond;
   guint timeout_id;
   guint poll_id;
   volatile gboolean read_ok;
   volatile gboolean finished;
-  volatile int ref_count;
-} WorkerSyncObject;
+  volatile gboolean interrupted;
+  volatile gboolean lock_and_cond_initialized;
+};
+
+
+struct _WorkerSyncObjectClass
+{
+  GObjectClass parent_class;
+};
+
+
+static void worker_sync_object_class_init(WorkerSyncObjectClass *klass);
+static void worker_sync_object_init(WorkerSyncObject *sync_object);
+static void worker_sync_object_finalize(GObject *object);
+
+
+static GType
+worker_sync_object_get_type(void)
+{
+  static GType sync_object_type = 0;
+
+  if (sync_object_type == 0)
+    {
+      static const GTypeInfo sync_object_info =
+	{
+	  sizeof(WorkerSyncObjectClass),
+	  NULL,	/* base_init */
+	  NULL,	/* base_finalize */
+	  (GClassInitFunc)worker_sync_object_class_init,
+	  NULL,	/* class_finalize */
+	  NULL,	/* class_data */
+	  sizeof(WorkerSyncObject),
+	  0,	/* n_preallocs */
+	  (GInstanceInitFunc)worker_sync_object_init,
+	};
+
+      sync_object_type = g_type_register_static(G_TYPE_OBJECT,
+						"WorkerSyncObject",
+						&sync_object_info, 0);
+    }
+
+  return sync_object_type;
+}
+
+
+GObjectClass *sync_object_parent_class = NULL;
+
+
+static void
+worker_sync_object_class_init(WorkerSyncObjectClass *klass)
+{
+  GObjectClass *o_class = G_OBJECT_CLASS(klass);
+  sync_object_parent_class = g_type_class_peek_parent(klass);
+  o_class->finalize = worker_sync_object_finalize;
+}
+
+
+static void
+worker_sync_object_init(WorkerSyncObject *sync_object)
+{
+  if (pthread_mutex_init(&sync_object->lock, NULL) != 0)
+    {
+      fprintf(stderr, "Couldn't init a mutex.\n");
+      abort();
+    }
+
+  if (pthread_cond_init(&sync_object->cond, NULL) != 0)
+    {
+      fprintf(stderr, "Couldn't init a condition.\n");
+      abort();
+    }
+  sync_object->lock_and_cond_initialized = TRUE;
+}
+
+
+static void
+worker_sync_object_finalize(GObject *object)
+{
+  WorkerSyncObject *sync_object = OCHUSHA_WORKER_SYNC_OBJECT(object);
+
+  if (sync_object->lock_and_cond_initialized)
+    {
+      if (pthread_mutex_destroy(&sync_object->lock) != 0)
+	{
+	  fprintf(stderr, "Couldn't destroy a mutex: errno=%d\n", errno);
+	  abort();
+	}
+      if (pthread_cond_destroy(&sync_object->cond) != 0)
+	{
+	  fprintf(stderr, "Couldn't destroy a condition: errno=%d\n", errno);
+	  abort();
+	}
+      sync_object->lock_and_cond_initialized = FALSE;
+    }
+
+  if (sync_object_parent_class->finalize)
+    (*sync_object_parent_class->finalize)(object);
+}
+
+
+static WorkerSyncObject *
+worker_sync_object_new(void)
+{
+  return OCHUSHA_WORKER_SYNC_OBJECT(g_object_new(OCHUSHA_TYPE_WORKER_SYNC_OBJECT, NULL));
+}
 
 
 #define LOCK_WORKER_SYNC_OBJECT(sync_object)			\
@@ -545,46 +660,6 @@ typedef struct _WorkerSyncObject
   while (0)
 
 
-static void
-ochusha_network_broker_worker_sync_object_free(WorkerSyncObject *sync_object)
-{
-  int count;
-  g_return_if_fail(sync_object->ref_count > 0 && sync_object->ref_count <= 2);
-
-#if DEBUG_NETWORK
-  fprintf(stderr, "entering: sync_object_free(%p)\n", sync_object);
-#endif
-
-  LOCK_WORKER_SYNC_OBJECT(sync_object);
-  count = --sync_object->ref_count;
-  UNLOCK_WORKER_SYNC_OBJECT(sync_object);
-
-#if DEBUG_NETWORK
-  fprintf(stderr, "leaving: sync_object_free(%p)\n", sync_object);
-#endif
-
-  if (count > 0)
-    return;
-
-#if DEBUG_NETWORK
-  fprintf(stderr, "sync_object_free(%p): done\n", sync_object);
-#endif
-
-  if (pthread_mutex_destroy(&sync_object->lock) != 0)
-    {
-      fprintf(stderr, "Couldn't destroy a mutex.\n");
-      abort();
-    }
-  if (pthread_cond_destroy(&sync_object->cond) != 0)
-    {
-      fprintf(stderr, "Couldn't destroy a condition.\n");
-      abort();
-    }
-
-  G_FREE(sync_object);
-}
-
-
 static gboolean
 timeout_cb(WorkerSyncObject *sync_object)
 {
@@ -592,6 +667,7 @@ timeout_cb(WorkerSyncObject *sync_object)
 #if DEBUG_NETWORK
   fprintf(stderr, "entering: timeout_cb(%p)\n", sync_object);
 #endif
+  g_return_val_if_fail(OCHUSHA_IS_WORKER_SYNC_OBJECT(sync_object), FALSE);
 
   LOCK_WORKER_SYNC_OBJECT(sync_object);
   finished = sync_object->finished;
@@ -609,7 +685,7 @@ timeout_cb(WorkerSyncObject *sync_object)
   if (!finished)
     return TRUE;
 
-  ochusha_network_broker_worker_sync_object_free(sync_object);
+  g_object_unref(G_OBJECT(sync_object));
 
   return FALSE;
 }
@@ -622,6 +698,7 @@ poll_cb(GIOChannel *channel, GIOCondition condition,
 #if DEBUG_NETWORK
   fprintf(stderr, "entering: poll_cb(%p)\n", sync_object);
 #endif
+  g_return_val_if_fail(OCHUSHA_IS_WORKER_SYNC_OBJECT(sync_object), FALSE);
 
   LOCK_WORKER_SYNC_OBJECT(sync_object);
   if (condition & (G_IO_IN | G_IO_PRI))
@@ -638,6 +715,7 @@ poll_cb(GIOChannel *channel, GIOCondition condition,
 #if DEBUG_NETWORK
   fprintf(stderr, "leaving: poll_cb(%p)\n", sync_object);
 #endif
+  g_object_unref(G_OBJECT(sync_object));
 
   return FALSE;
 }
@@ -647,12 +725,13 @@ static void
 register_polling_function_for_read(WorkerSyncObject *sync_object, int fd)
 {
   LOCK_WORKER_SYNC_OBJECT(sync_object);
+  g_object_ref(G_OBJECT(sync_object));
   if (sync_object->poll_id == 0)
     {
       GIOChannel *channel = g_io_channel_unix_new(fd);
       sync_object->poll_id
 	= g_io_add_watch_full(channel,
-			      G_PRIORITY_DEFAULT_IDLE,
+			      G_PRIORITY_DEFAULT,
 			      G_IO_IN|G_IO_PRI|G_IO_ERR|G_IO_HUP|G_IO_NVAL,
 			      (GIOFunc)poll_cb, sync_object, NULL);
       g_io_channel_unref(channel);
@@ -747,10 +826,27 @@ http_read_from_url(OchushaNetworkBroker *broker, OchushaAsyncBuffer *buffer)
       gboolean read_ok;
 
       LOCK_WORKER_SYNC_OBJECT(sync_object);
-      if ((read_ok = sync_object->read_ok) || sock_fd == -1)
+      if (sync_object->interrupted)
 	{
+	  read_ok = FALSE;
+	  sync_object->interrupted = FALSE;
+	}
+      else if ((read_ok = sync_object->read_ok)
+	       || (state == ghttp_not_done && sock_fd == -1))
+	{
+#if 0
+	  struct timeval before;
+	  struct timeval after;
+	  gettimeofday(&before, NULL);
+#endif
 	  state = ghttp_process(request);
 	  sync_object->read_ok = FALSE;
+#if 0
+	  gettimeofday(&after, NULL);
+	  fprintf(stderr, "ghttp_process() consumes %ld.%ld (sec).\n",
+		  (after.tv_sec - before.tv_sec),
+		  (after.tv_usec - before.tv_usec) * 100000);
+#endif
 	}
       UNLOCK_WORKER_SYNC_OBJECT(sync_object);
 
@@ -956,7 +1052,7 @@ http_read_from_url(OchushaNetworkBroker *broker, OchushaAsyncBuffer *buffer)
 	}
 
       LOCK_WORKER_SYNC_OBJECT(sync_object);
-      if (!sync_object->read_ok
+      if (!sync_object->interrupted && !sync_object->read_ok
 	  && pthread_cond_wait(&sync_object->cond, &sync_object->lock) != 0)
 	{
 	  fprintf(stderr, "Couldn't wait a condition.\n");
@@ -1103,6 +1199,7 @@ wakeup_now_cb(OchushaAsyncBuffer *buffer, WorkerSyncObject *sync_object)
 #endif
 
   LOCK_WORKER_SYNC_OBJECT(sync_object);
+  sync_object->interrupted = TRUE;
   if (pthread_cond_signal(&sync_object->cond) != 0)
     {
       fprintf(stderr, "Couldn't signal a condition.\n");
@@ -1116,6 +1213,19 @@ wakeup_now_cb(OchushaAsyncBuffer *buffer, WorkerSyncObject *sync_object)
 }
 
 
+static void
+ochusha_network_broker_worker_sync_object_free(WorkerSyncObject *sync_object)
+{
+  g_return_if_fail(OCHUSHA_IS_WORKER_SYNC_OBJECT(sync_object));
+
+#if DEBUG_NETWORK
+  fprintf(stderr, "entering: sync_object_free(%p)\n", sync_object);
+#endif
+
+  g_object_unref(G_OBJECT(sync_object));
+}
+
+
 static OchushaAsyncBuffer *
 ochusha_network_broker_employ_worker_thread(OchushaNetworkBroker *broker,
 					    const char *url,
@@ -1124,29 +1234,16 @@ ochusha_network_broker_employ_worker_thread(OchushaNetworkBroker *broker,
 {
   NetworkBrokerJobArgs *args;
   WorkerJob *job;
-  WorkerSyncObject *sync_object = G_NEW0(WorkerSyncObject, 1);
+  WorkerSyncObject *sync_object = worker_sync_object_new();
   OchushaNetworkBrokerBufferStatus *status
     = G_NEW0(OchushaNetworkBrokerBufferStatus, 1);
   OchushaAsyncBuffer *buffer = ochusha_async_buffer_new(NULL, 0, NULL);
 
-  if (pthread_mutex_init(&sync_object->lock, NULL) != 0)
-    {
-      fprintf(stderr, "Couldn't init a mutex.\n");
-      abort();
-    }
-
-  if (pthread_cond_init(&sync_object->cond, NULL) != 0)
-    {
-      fprintf(stderr, "Couldn't init a condition.\n");
-      abort();
-    }
-
-  sync_object->ref_count = 2;
-
-  g_object_set_qdata_full(G_OBJECT(buffer), broker_buffer_status_id, status,
-		(GDestroyNotify)ochusha_network_broker_buffer_status_free);
   g_object_set_qdata_full(G_OBJECT(buffer), worker_sync_object_id, sync_object,
 		(GDestroyNotify)ochusha_network_broker_worker_sync_object_free);
+  g_object_set_qdata_full(G_OBJECT(buffer), broker_buffer_status_id, status,
+		(GDestroyNotify)ochusha_network_broker_buffer_status_free);
+
   g_signal_connect(G_OBJECT(buffer), "wakeup_now",
 		   G_CALLBACK(wakeup_now_cb), sync_object);
 
@@ -1173,6 +1270,7 @@ ochusha_network_broker_employ_worker_thread(OchushaNetworkBroker *broker,
   job->args = buffer;
 
   /* åɤΤ˳ */
+  g_object_ref(G_OBJECT(sync_object));
   g_object_ref(G_OBJECT(broker));
   g_object_ref(G_OBJECT(buffer));
 
@@ -1352,10 +1450,27 @@ try_update_cache(WorkerThread *employee, OchushaAsyncBuffer *buffer)
 	  gboolean read_ok;
 
 	  LOCK_WORKER_SYNC_OBJECT(sync_object);
-	  if ((read_ok = sync_object->read_ok) || sock_fd == -1)
+	  if (sync_object->interrupted)
 	    {
+	      read_ok = FALSE;
+	      sync_object->interrupted = FALSE;
+	    }
+	  else if ((read_ok = sync_object->read_ok)
+		   || (state == ghttp_not_done && sock_fd == -1))
+	    {
+#if 0
+	      struct timeval before;
+	      struct timeval after;
+	      gettimeofday(&before, NULL);
+#endif
 	      state = ghttp_process(request);
 	      sync_object->read_ok = FALSE;
+#if 0
+	      gettimeofday(&after, NULL);
+	      fprintf(stderr, "ghttp_process() consumes %ld.%ld (sec).\n",
+		      (after.tv_sec - before.tv_sec),
+		      (after.tv_usec - before.tv_usec) * 100000);
+#endif
 	    }
 	  UNLOCK_WORKER_SYNC_OBJECT(sync_object);
 
@@ -1580,7 +1695,7 @@ try_update_cache(WorkerThread *employee, OchushaAsyncBuffer *buffer)
 	    }
 
 	  LOCK_WORKER_SYNC_OBJECT(sync_object);
-	  if (!sync_object->read_ok
+	  if (!sync_object->interrupted && !sync_object->read_ok
 	      && pthread_cond_wait(&sync_object->cond,
 				   &sync_object->lock) != 0)
 	    {
@@ -2495,8 +2610,8 @@ ochusha_network_broker_try_post(OchushaNetworkBroker *broker,
     {
       const char *set_cookie;
       status->status_code = ghttp_status_code(request);
-      status->body = G_MEMDUP(ghttp_get_body(request),
-			      ghttp_get_body_len(request));
+      status->body = G_STRNDUP(ghttp_get_body(request),
+			       ghttp_get_body_len(request));
       set_cookie = ghttp_get_header(request, http_hdr_Set_Cookie);
       if (set_cookie != NULL)
 	status->set_cookie = G_STRDUP(set_cookie);
